summaryrefslogtreecommitdiff
path: root/src/cython
diff options
context:
space:
mode:
authorpdlotko <pdlotko@636b058d-ea47-450e-bf9e-a15bfbe3eedb>2017-08-22 13:26:44 +0000
committerpdlotko <pdlotko@636b058d-ea47-450e-bf9e-a15bfbe3eedb>2017-08-22 13:26:44 +0000
commitc415445c6a30cfdc7abc63dba23e4eb5e7ff98da (patch)
tree48f37ad44c87c351d363dfb29b8bc832f416c941 /src/cython
parent40db1989840aa9e485233354853ad09239272ad7 (diff)
cleaning up the mess with names.
git-svn-id: svn+ssh://scm.gforge.inria.fr/svnroot/gudhi/branches/persistence_representation_integration@2617 636b058d-ea47-450e-bf9e-a15bfbe3eedb Former-commit-id: cd558be592a050f598fc5a22e012a31b7690c5c6
Diffstat (limited to 'src/cython')
-rw-r--r--src/cython/cython/persistence_representations_intervals.pyx (renamed from src/cython/cython/persistence_representations_diagrams.pyx)6
-rw-r--r--src/cython/gudhi.pyx.in2
-rw-r--r--src/cython/include/persistence_representations_intervals.h (renamed from src/cython/include/persistence_representations_diagrams.h)4
3 files changed, 6 insertions, 6 deletions
diff --git a/src/cython/gudhi.pyx.in b/src/cython/gudhi.pyx.in
index 6bb6dce9..62b593e1 100644
--- a/src/cython/gudhi.pyx.in
+++ b/src/cython/gudhi.pyx.in
@@ -32,7 +32,7 @@ include "cython/periodic_cubical_complex.pyx"
include "cython/persistence_graphical_tools.py"
include "cython/witness_complex.pyx"
include "cython/strong_witness_complex.pyx"
-include "cython/persistence_representations_diagrams.pyx"
+include "cython/persistence_representations_intervals.pyx"
@GUDHI_CYTHON_ALPHA_COMPLEX@
@GUDHI_CYTHON_EUCLIDEAN_WITNESS_COMPLEX@
@GUDHI_CYTHON_SUBSAMPLING@
diff --git a/src/cython/include/persistence_representations_diagrams.h b/src/cython/include/persistence_representations_intervals.h
index aed2304c..eb440f1a 100644
--- a/src/cython/include/persistence_representations_diagrams.h
+++ b/src/cython/include/persistence_representations_intervals.h
@@ -20,8 +20,8 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef INCLUDE_PERSISTENCE_REPRESENTATIONS_DIAGRAMS_
-#define INCLUDE_PERSISTENCE_REPRESENTATIONS_DIAGRAMS_
+#ifndef INCLUDE_PERSISTENCE_REPRESENTATIONS_INTERVALS_
+#define INCLUDE_PERSISTENCE_REPRESENTATIONS_INTERVALS_
#include <gudhi/Persistence_intervals.h>
diff --git a/src/cython/cython/persistence_representations_diagrams.pyx b/src/cython/cython/persistence_representations_intervals.pyx
index 45ab4828..29027801 100644
--- a/src/cython/cython/persistence_representations_diagrams.pyx
+++ b/src/cython/cython/persistence_representations_intervals.pyx
@@ -40,7 +40,7 @@ This is a promisse that there will be a class in this file with the following fu
According to Vincent, most of the tutorials in cython suggest to separate pre-declaration below with the definition of the method. Hovewer it seems to create problems, that is why we keep them both here.
"""
-cdef extern from "persistence_representations_diagrams.h" namespace "Gudhi::Persistence_representations":
+cdef extern from "persistence_representations_intervals.h" namespace "Gudhi::Persistence_representations":
cdef cppclass Persistence_intervals_interface "Gudhi::Persistence_representations::Persistence_intervals_interface":
Persistence_intervals_interface()
Persistence_intervals_interface(const char* , unsigned )
@@ -67,11 +67,11 @@ to separate the function, use newline. Put there only C++ signature
#convention for python class is PersistenceDiagrams instead of Persistence_diagrams
#for methods it is def num_simplices(self).
cdef class PersistenceIntervals:
"""
- Persistence interals is a standard representation of persistent homology. This file provide implementation of a number of operations on persistence diagrams.
+ Persistence intrvals is a standard representation of persistent homology. This file provide implementation of a number of operations on persistence diagrams.
"""
cdef Persistence_intervals_interface * thisptr
@@ -67,11 +67,11 @@ to separate the function, use newline. Put there only C++ signature
Persistence_intervals_interface(const char* , unsigned )
-#convention for python class is PersistenceDiagrams instead of Persistence_diagrams
+#convention for python class is PersistenceIntervals instead of Persistence_intervals
#for methods it is def num_simplices(self).
cdef class PersistenceIntervals: